@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Settings
- * @version    $Id: 110.accounts.php 632 2010-03-17 07:51:16Z d00p $
+ * @version    $Id: 110.accounts.php 1189 2010-07-19 08:06:18Z d00p $
  */
 
 return array(
@@ -62,6 +62,15 @@ return array(
 					'default' => 0,
 					'save_method' => 'storeSettingField',
 					),
+				'panel_password_regex' => array(
+					'label' => $lng['serversettings']['panel_password_regex'],
+					'settinggroup' => 'panel',
+					'varname' => 'password_regex',
+					'type' => 'string',
+					'default' => '',
+					/* 'plausibility_check_method' => 'checkValidRegEx', */
+					'save_method' => 'storeSettingField',
+					),
 				'customer_accountprefix' => array(
 					'label' => $lng['serversettings']['accountprefix'],
 					'settinggroup' => 'customer',
