@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Settings
- * @version    $Id: 140.statistics.php 745 2010-04-08 10:28:48Z d00p $
+ * @version    $Id: 140.statistics.php 1246 2010-08-10 12:07:53Z d00p $
  */
 
 return array(
@@ -49,6 +49,15 @@ return array(
 					'default' => '/usr/bin/',
 					'save_method' => 'storeSettingField',
 					),
+				'system_awstats_awstatspath' => array(
+					'label' => $lng['serversettings']['awstats_awstatspath'],
+					'settinggroup' => 'system',
+					'varname' => 'awstats_awstatspath',
+					'type' => 'string',
+					'string_type' => 'dir',
+					'default' => '/usr/bin/',
+					'save_method' => 'storeSettingField',
+					),
 				'system_awstats_conf' => array(
 					'label' => $lng['serversettings']['awstats_conf'],
 					'settinggroup' => 'system',
