@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Settings
- * @version    $Id: 160.nameserver.php 1006 2010-05-27 20:34:49Z d00p $
+ * @version    $Id: 160.nameserver.php 1045 2010-06-02 10:08:01Z d00p $
  */
 
 return array(
@@ -59,6 +59,14 @@ return array(
 					'default' => '',
 					'save_method' => 'storeSettingField',
 					),
+				'system_dns_createmailentry' => array(
+					'label' => $lng['serversettings']['mail_also_with_mxservers'],
+					'settinggroup' => 'system',
+					'varname' => 'dns_createmailentry',
+					'type' => 'bool',
+					'default' => false,
+					'save_method' => 'storeSettingField'
+					),
 				'system_defaultttl' => array(
 					'label' => $lng['serversettings']['defaultttl'],
 					'settinggroup' => 'system',
