@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Panel
- * @version    $Id: customer_domains.php 930 2010-05-12 06:52:11Z d00p $
+ * @version    $Id: customer_domains.php 1249 2010-08-12 12:32:26Z d00p $
  */
 
 define('AREA', 'customer');
@@ -374,7 +374,7 @@ elseif($page == 'domains')
 					$codes = getRedirectCodesArray();
 					foreach($codes as $rc)
 					{
-						$redirectcode .= makeoption($rc['code'], $rc['id'], $settings['customredirect']['default']);
+						$redirectcode .= makeoption($rc['code']. ' ('.$lng['redirect_desc'][$rc['desc']].')', $rc['id'], $settings['customredirect']['default']);
 					}
 				}
 
@@ -552,7 +552,7 @@ elseif($page == 'domains')
 					$codes = getRedirectCodesArray();
 					foreach($codes as $rc)
 					{
-						$redirectcode .= makeoption($rc['code'], $rc['id'], $def_code);
+						$redirectcode .= makeoption($rc['code']. ' ('.$lng['redirect_desc'][$rc['desc']].')', $rc['id'], $def_code);
 					}
 				}
 
