@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Panel
- * @version    $Id: customer_ftp.php 1188 2010-07-19 06:03:49Z d00p $
+ * @version    $Id: customer_ftp.php 1245 2010-08-10 09:21:07Z d00p $
  */
 
 define('AREA', 'customer');
@@ -212,11 +212,15 @@ elseif($page == 'accounts')
 							'USR_PATH' => makeCorrectDir(substr($path, strlen($userinfo['documentroot'])))
 						);
 						
-						$mail_body = replace_variables($lng['customer']['ftp_add']['infomail_body']['main'], $replace_arr);
+						$def_language = $userinfo['def_language'];
+						$result = $db->query_first('SELECT `value` FROM `' . TABLE_PANEL_TEMPLATES . '` WHERE `adminid`=\'' . (int)$userinfo['adminid'] . '\' AND `language`=\'' . $db->escape($def_language) . '\' AND `templategroup`=\'mails\' AND `varname`=\'new_ftpaccount_by_customer_subject\'');
+						$mail_subject = html_entity_decode(replace_variables((($result['value'] != '') ? $result['value'] : $lng['customer']['ftp_add']['infomail_subject']), $replace_arr));
+						$result = $db->query_first('SELECT `value` FROM `' . TABLE_PANEL_TEMPLATES . '` WHERE `adminid`=\'' . (int)$userinfo['adminid'] . '\' AND `language`=\'' . $db->escape($def_language) . '\' AND `templategroup`=\'mails\' AND `varname`=\'new_ftpaccount_by_customer_mailbody\'');
+						$mail_body = html_entity_decode(replace_variables((($result['value'] != '') ? $result['value'] : $lng['customer']['ftp_add']['infomail_body']['main']), $replace_arr));
 						
 						$_mailerror = false;
 						try {
-							$mail->Subject = $lng['customer']['ftp_add']['infomail_subject'];
+							$mail->Subject = $mail_subject;
 							$mail->AltBody = $mail_body;
 							$mail->MsgHTML(str_replace("\n", "<br />", $mail_body));
 							$mail->AddAddress($userinfo['email'], getCorrectUserSalutation($userinfo));
@@ -242,7 +246,7 @@ elseif($page == 'accounts')
 			}
 			else
 			{
-				$pathSelect = makePathfield($userinfo['documentroot'], $userinfo['guid'], $userinfo['guid'], $settings['panel']['pathedit']);
+				$pathSelect = makePathfield($userinfo['documentroot'], $userinfo['guid'], $userinfo['guid'], $settings['panel']['pathedit'], '/');
 
 				if($settings['customer']['ftpatdomain'] == '1')
 				{
