@@ -12,7 +12,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Language
- * @version    $Id: preconfig_0.9.inc.php 1290 2010-09-20 07:56:32Z d00p $
+ * @version    $Id: preconfig_0.9.inc.php 1321 2010-10-01 06:10:45Z d00p $
  */
 
 /**
@@ -291,4 +291,23 @@ function parseAndOutputPreconfig(&$has_preconfig, &$return, $current_version)
 			eval("\$return.=\"" . getTemplate("update/preconfigitem") . "\";");
 		}
 	}
+
+	if(versionInUpdate($current_version, '0.9.13.1'))
+	{
+		if((int)$settings['system']['mod_fcgid_ownvhost'] == 1)
+		{
+			$has_preconfig = true;
+			$description = 'You have FCGID for Froxlor itself activated. You can now specify a PHP-configuration for this.';
+			$question = '<strong>Select Froxlor-vhost PHP configuration:</strong>&nbsp;';
+			$question .= '<select name="update_defaultini_ownvhost">';
+			$configs_array = getPhpConfigs();
+			$configs = '';
+			foreach($configs_array as $idx => $desc)
+			{
+				$configs .= makeoption($desc, $idx, '1');
+			}
+			$question .= $configs.'</select>';
+			eval("\$return.=\"" . getTemplate("update/preconfigitem") . "\";");
+		}
+	}
 }
