@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Logger
- * @version    $Id: class.ticket.php 1298 2010-09-23 07:45:04Z d00p $
+ * @version    $Id: class.ticket.php 1318 2010-09-30 12:53:34Z d00p $
  * @link       http://www.nutime.de/
  *
  * Support Tickets - Tickets-Class
@@ -87,7 +87,7 @@ class ticket
 		$this->tid = $tid;
 
 		// initialize purifier
-		require_once '../htmlpurifier/library/HTMLPurifier.auto.php';
+		require_once dirname(dirname(__FILE__)).'/htmlpurifier/library/HTMLPurifier.auto.php';
 		$this->_purifier = new HTMLPurifier();
 
 		// initialize data array
