@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Configfiles
- * @version    $Id: hardy.inc.php 1206 2010-07-28 06:08:14Z d00p $
+ * @version    $Id: hardy.inc.php 1277 2010-09-13 06:11:25Z d00p $
  */
 
 return Array(
@@ -108,16 +108,19 @@ return Array(
 							'touch /etc/postfix/mysql-virtual_alias_maps.cf',
 							'touch /etc/postfix/mysql-virtual_mailbox_domains.cf',
 							'touch /etc/postfix/mysql-virtual_mailbox_maps.cf',
+							'touch /etc/postfix/mysql-virtual_sender_permissions.cf',
 							'touch /etc/postfix/sasl/smtpd.conf',
 							'chown root:root /etc/postfix/main.cf',
 							'chown root:postfix /etc/postfix/mysql-virtual_alias_maps.cf',
 							'chown root:postfix /etc/postfix/mysql-virtual_mailbox_domains.cf',
 							'chown root:postfix /etc/postfix/mysql-virtual_mailbox_maps.cf',
+							'chown root:postfix /etc/postfix/mysql-virtual_sender_permissions.cf',
 							'chown root:root /etc/postfix/sasl/smtpd.conf',
 							'chmod 0644 /etc/postfix/main.cf',
 							'chmod 0640 /etc/postfix/mysql-virtual_alias_maps.cf',
 							'chmod 0640 /etc/postfix/mysql-virtual_mailbox_domains.cf',
 							'chmod 0640 /etc/postfix/mysql-virtual_mailbox_maps.cf',
+							'chmod 0640 /etc/postfix/mysql-virtual_sender_permissions.cf',
 							'chmod 0600 /etc/postfix/sasl/smtpd.conf',
 						),
 						'files' => Array(
@@ -125,6 +128,7 @@ return Array(
 							'etc_postfix_mysql-virtual_alias_maps.cf' => '/etc/postfix/mysql-virtual_alias_maps.cf',
 							'etc_postfix_mysql-virtual_mailbox_domains.cf' => '/etc/postfix/mysql-virtual_mailbox_domains.cf',
 							'etc_postfix_mysql-virtual_mailbox_maps.cf' => '/etc/postfix/mysql-virtual_mailbox_maps.cf',
+							'etc_postfix_mysql-virtual_sender_permissions.cf' => '/etc/postfix/mysql-virtual_sender_permissions.cf',
 							'etc_postfix_sasl_smtpd.conf' => '/etc/postfix/sasl/smtpd.conf'
 						),
 						'restart' => Array(
@@ -145,23 +149,27 @@ return Array(
 							'touch /etc/postfix/mysql-virtual_alias_maps.cf',
 							'touch /etc/postfix/mysql-virtual_mailbox_domains.cf',
 							'touch /etc/postfix/mysql-virtual_mailbox_maps.cf',
+							'touch /etc/postfix/mysql-virtual_sender_permissions.cf',
 							'chown root:root /etc/postfix/main.cf',
 							'chown root:root /etc/postfix/master.cf',
 							'chown root:postfix /etc/postfix/mysql-virtual_alias_maps.cf',
 							'chown root:postfix /etc/postfix/mysql-virtual_mailbox_domains.cf',
 							'chown root:postfix /etc/postfix/mysql-virtual_mailbox_maps.cf',
+							'chown root:postfix /etc/postfix/mysql-virtual_sender_permissions.cf',
 							'chmod 0644 /etc/postfix/main.cf',
 							'chmod 0644 /etc/postfix/master.cf',
 							'chmod 0640 /etc/postfix/mysql-virtual_alias_maps.cf',
 							'chmod 0640 /etc/postfix/mysql-virtual_mailbox_domains.cf',
 							'chmod 0640 /etc/postfix/mysql-virtual_mailbox_maps.cf',
+							'chmod 0640 /etc/postfix/mysql-virtual_sender_permissions.cf'
 						),
 						'files' => Array(
 							'etc_postfix_main.cf' => '/etc/postfix/main.cf',
 							'etc_postfix_master.cf' => '/etc/postfix/master.cf',
 							'etc_postfix_mysql-virtual_alias_maps.cf' => '/etc/postfix/mysql-virtual_alias_maps.cf',
 							'etc_postfix_mysql-virtual_mailbox_domains.cf' => '/etc/postfix/mysql-virtual_mailbox_domains.cf',
-							'etc_postfix_mysql-virtual_mailbox_maps.cf' => '/etc/postfix/mysql-virtual_mailbox_maps.cf'
+							'etc_postfix_mysql-virtual_mailbox_maps.cf' => '/etc/postfix/mysql-virtual_mailbox_maps.cf',
+							'etc_postfix_mysql-virtual_sender_permissions.cf' => '/etc/postfix/mysql-virtual_sender_permissions.cf'
 						),
 						'restart' => Array(
 							'/etc/init.d/postfix restart',
