@@ -16,7 +16,7 @@
  * @author     Froxlor Team <team@froxlor.org>
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Language
- * @version    $Id: portugues.lng.php 705 2010-04-01 05:52:32Z d00p $
+ * @version    $Id: portugues.lng.php 759 2010-04-09 19:24:17Z EleRas $
  */
 
 /**
@@ -379,7 +379,6 @@ $lng['serversettings']['pathedit']['description'] = 'A escolha do file tem que s
  * ADDED BETWEEN 1.2.12 and 1.2.13
  */
 
-$lng['admin']['cronlastrun'] = 'Ultimo Agendamento';
 $lng['serversettings']['paging']['title'] = 'Entradas por pagina';
 $lng['serversettings']['paging']['description'] = 'Quantas entradas devem ser mostradas por pagina? (0 = desabilitar paginas)';
 $lng['error']['ipstillhasdomains'] = 'O IP/Porta que voce quer deletar ainda possui dominios associados e eles, por favor altere o IP/Porta destes dominios antes de delet&aacute;-los.';
@@ -490,7 +489,6 @@ $lng['admin']['configfiles']['etc'] = 'Outros (Sistema)';
 $lng['admin']['configfiles']['choosedistribution'] = 'Escolha uma distribui&ccedil;&atilde;o';
 $lng['admin']['configfiles']['chooseservice'] = 'Escolha um servi&ccedil;o';
 $lng['admin']['configfiles']['choosedaemon'] = 'Escolha um daemon';
-$lng['admin']['trafficlastrun'] = 'C&aacute;lculo do &Uacute;ltimo Tr&aacute;fego';
 $lng['serversettings']['ftpdomain']['title'] = 'Contas FTP @dom&iacute;nio';
 $lng['serversettings']['ftpdomain']['description'] = 'Clientes podem criar contas de FTP user@dom&iacute;niodocliente?';
 $lng['panel']['back'] = 'Volta';
@@ -738,8 +736,6 @@ $lng['error']['cannotuseawstatsandwebalizeratonetime'] = 'Voc&ecirc; n&atilde;o
 $lng['serversettings']['webalizer_enabled'] = 'Ativar estat&iacute;sticas webalizer';
 $lng['serversettings']['awstats_enabled'] = 'Ativar estat&iacute;sticas awstats';
 $lng['admin']['awstatssettings'] = 'Configura&ccedil;&otilde;es Awtats';
-$lng['serversettings']['awstats_domain_file']['title'] = 'Awstats diret&oacute;rio de arquivos do dominio';
-$lng['serversettings']['awstats_model_file']['title'] = 'Modelo de arquivo Awstats';
 $lng['admin']['domain_dns_settings'] = 'Configura&ccedil;&otilde;es de DNS';
 $lng['dns']['destinationip'] = 'Dom&iacute;nio IP';
 $lng['dns']['standardip'] = 'IP padr&atilde;o do servidor';
@@ -789,13 +785,6 @@ $lng['panel']['default'] = 'Padr&atilde;o';
 $lng['panel']['never'] = 'Nunca';
 $lng['panel']['active'] = 'Ativo';
 $lng['panel']['please_choose'] = 'Por favor escolha';
-$lng['panel']['intervalfee_type']['y'] = 'Anos';
-$lng['panel']['intervalfee_type']['m'] = 'Meses';
-$lng['panel']['intervalfee_type']['d'] = 'Dias';
-$lng['panel']['intervalfee_type_one']['y'] = 'Ano';
-$lng['panel']['intervalfee_type_one']['m'] = 'Mes';
-$lng['panel']['intervalfee_type_one']['d'] = 'Dia';
-$lng['panel']['service_still_active'] = 'Servi&ccedil;o ainda ativo';
 $lng['panel']['allow_modifications'] = 'Aceita altera&ccedil;oes';
 $lng['domains']['add_date'] = 'Adicionado no Froxlor';
 $lng['domains']['registration_date'] = 'Adicionado no Registro';
@@ -803,46 +792,9 @@ $lng['domains']['topleveldomain'] = 'Top-Level-Domain';
 $lng['admin']['accountdata'] = 'Data da Conta';
 $lng['admin']['contactdata'] = 'Data de Contato';
 $lng['admin']['servicedata'] = 'Data de Servi&ccedil;o';
-$lng['customer']['taxid'] = 'ID de Taxa';
-$lng['customer']['calc_tax'] = 'Calcular Taxa';
-$lng['customer']['create_contract'] = 'Criar contrato';
-$lng['customer']['contract_date'] = 'Data de contrato';
-$lng['customer']['contract_number'] = 'Descri&ccedil;&atilde;o/N&uacute;mero de contrato';
-$lng['customer']['additional_service_description'] = 'Descri&ccedil;&atilde;o adicional de servi&ccedil;o';
-$lng['customer']['contract_details'] = 'Detalhes do contrato';
-$lng['customer']['included_domains'] = 'Dom&iacute;nios Inclu&iacute;dos';
-$lng['customer']['additional_traffic'] = 'Tr&aacute;fego Adicional';
-$lng['customer']['additional_diskspace'] = 'Espaco Web Adicional';
-$lng['customer']['term_of_payment'] = 'Termo de Pagamento (dias)';
-$lng['customer']['payment_every'] = 'Pagamento todo';
-$lng['customer']['payment_method'] = 'M&eacute;todo de Pagamento';
-$lng['admin']['customer_categories_once'] = 'Incluir configura&ccedil;&otilde;es de taxas de clientes';
-$lng['admin']['customer_categories_period'] = 'Incluir intervalo de tavas de clientes';
-$lng['customer']['bankaccount_holder'] = 'Propriet&aacute;rio da conta';
-$lng['customer']['bankaccount_number'] = 'N&uacute;mero da conta';
-$lng['customer']['bankaccount_blz'] = 'N&uacute;mero da ag&ecirc;ncia';
-$lng['customer']['bankaccount_bank'] = 'Nome do banco';
-$lng['service']['quantity'] = 'Quantidade';
-$lng['service']['interval_fee'] = 'Pausa de TAXA';
-$lng['service']['interval_length'] = 'Pausa de Tempo';
-$lng['service']['interval_payment'] = 'Pausa de Pagamento';
-$lng['service']['interval_payment_prepaid'] = 'Pr&eacute; Pago';
-$lng['service']['interval_payment_postpaid'] = 'P&oacute;s Pago';
-$lng['service']['setup_fee'] = 'Configurar Taxa';
-$lng['service']['active'] = 'Ativa Servi&ccedil;o';
-$lng['service']['start_date'] = 'Activado desde';
-$lng['service']['end_date'] = 'Inativo desde';
-$lng['service']['valid_from'] = 'V&aacute;lido de';
-$lng['service']['valid_to'] = 'V&aacute;lido para';
 $lng['serversettings']['allow_password_reset']['description'] = 'Os clientes podem redefinir sua senha e  ser&atilde;o enviadas para seu endere&ccedil;o de e-mail';
 $lng['serversettings']['allow_password_reset_admin']['title'] = 'Ativa reset de senhas pelos administradores';
 $lng['serversettings']['allow_password_reset_admin']['description'] = 'Admins / Revendedor pode redefinir sua senha e a nova senha ser&aacute; enviada para seu endere&ccedil;o de e-mail';
-$lng['emails']['quota_type']['byte'] = 'B';
-$lng['emails']['quota_type']['kilobyte'] = 'KB';
-$lng['emails']['quota_type']['megabyte'] = 'MB';
-$lng['emails']['quota_type']['gigabyte'] = 'GB';
-$lng['emails']['quota_type']['terabyte'] = 'TB';
-$lng['emails']['quota_type']['petabyte'] = 'PB';
 $lng['panel']['not_supported'] = 'N&atilde;o suportado em:';
 $lng['menue']['email']['autoresponder'] = 'Auto-Responder';
 $lng['autoresponder']['active'] = 'Ativar';
